from .api.ThermiaAPI import ThermiaAPI
from .model.WaterHeater import ThermiaWaterHeater

class Thermia():
    def __init__(self, username, password):
        self.api_interface = ThermiaAPI(username, password)
        self.connected = self.api_interface.authenticated
        self.water_heaters = self.__get_water_heaters()

    def __get_water_heaters(self):
        devices = self.api_interface.get_devices()
        water_heaters = []

        for device in devices:
            water_heaters.append(ThermiaWaterHeater(device, self.api_interface))

        return water_heaters



from distutils.core import setup

setup(
  name='ThermiaOnlineAPI',
  packages=['ThermiaOnlineAPI'],
  version='1.0.0',
  license='GPL-3.0',
  description='A Python API for Thermia heat pumps using https://online.thermia.se',
  author='Krisjanis Lejejs',
  author_email='krisjanis.lejejs@gmail.com',
  url='https://github.com/klejejs/python-thermia-online-api',
  download_url='https://github.com/klejejs/python-thermia-online-api/archive/refs/tags/1.0.0.zip',
  keywords=['Thermia', 'Online'],
  install_requires=[],
  classifiers=[],
)